@@ -101,6 +101,9 @@ snippet = {
                         "    \"n2\": 64,",
                         "    \"output_size\": 1,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -129,6 +132,9 @@ snippet = {
                         "    \"n2\": 64,",
                         "    \"output_size\": 1,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -159,6 +165,9 @@ snippet = {
                         "model_config = {",
                         "    \"output_size\": len(train_set.classes),",
                         "    \"fc_dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -186,6 +195,9 @@ snippet = {
                         "    \"hidden_size\": 64,",
                         "    \"num_layers\": 2,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -215,6 +227,9 @@ snippet = {
                         "    \"hidden_size\": 64,",
                         "    \"num_layers\": 2,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -242,6 +257,9 @@ snippet = {
                         "    \"hidden_size\": 64,",
                         "    \"num_layers\": 2,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -272,6 +290,9 @@ snippet = {
                         "    \"hidden_size\": 64,",
                         "    \"num_layers\": 2,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -299,6 +320,9 @@ snippet = {
                         "    \"hidden_size\": 64,",
                         "    \"num_layers\": 2,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 },
@@ -328,6 +352,9 @@ snippet = {
                         "    \"hidden_size\": 64,",
                         "    \"num_layers\": 2,",
                         "    \"dropout\": 0",
+                        "}",
+                        "optimizer_config = {",
+                        "    \"lr\": 0.001",
                         "}"
                     ]
                 }
@@ -336,10 +363,10 @@ snippet = {
         {
             "name": "Training Preparation (MCOC)",
             "snippet": [
-                "model = _______(**config).to(device)",
+                "model = _______(**model_config).to(device)",
                 "criterion = _______",
-                "optimizer = optim.AdamW(model.parameters(), lr=0.001)",
-                "callback = Callback(model, optimizer, config, metadata, outdir=\"output\")"
+                "optimizer = optim.AdamW(model.parameters(), **optimizer_config)",
+                "callback = Callback(model, optimizer, model_config, optimizer_config, metadata, outdir=\"output\")"
             ]
         },
         {
@@ -576,7 +603,8 @@ snippet = {
                     "snippet": [
                         "from jcopdl.io import load_from_checkpoint",
                         "",                       
-                        "model, optimizer, callback = load_from_checkpoint(checkpoint_path)"
+                        "model, optimizer, callback = load_from_checkpoint(\"output/checkpoint/_________.pth\")",
+                        "criterion = _______"
                     ]
                 },{
                     "name": "Load best model",
